from .core.factory import CollinsDictionary, OxfordDictionary, VocabularyDictionary

LexicoDictionary = OxfordDictionary
__all__ = (CollinsDictionary, LexicoDictionary,
           OxfordDictionary, VocabularyDictionary)
